# min-pypi-hello

A minimalist example of PyPI packaging.
( [view on pypi](https://pypi.python.org/pypi?name=minpypihello&version=1.0&:action=display) )

   * A module of called `minpypihello` that you can import and print a helloworld.
   * A script that can be executed directly to print a helloworld message.

## Distribute to PyPI

Register: Use `python setup.py register` and go through the procedure as prompt. 

Build source archive: `python setup.py sdist`.

Upload: `python setup.py upload`.

[more info.](http://docs.python.org/2/distutils/packageindex.html)

## Reference

   * distutils: 
   <http://docs.python.org/2/distutils/>
   * A list of package metadata: 
   <http://docs.python.org/2/distutils/setupscript.html#additional-meta-data>
